@@ -1,20 +1,23 @@
 package Math::Random::Normal::Leva;
 use strict;
 use warnings;
-our $VERSION = "0.02";
-$VERSION = eval $VERSION;
-require Exporter;
-our @ISA       = qw(Exporter);
+
+our $VERSION = "0.03";
+
+use Exporter qw(import export_to_level);
 our @EXPORT_OK = qw(gbm_sample random_normal);
+
 use Math::Random::Secure qw(rand);
 
+use Carp qw(confess);
+
 =head1 NAME
 
 Math::Random::Normal::Leva - generate normally distributed PRN using Leva method
 
 =head1 VERSION
 
-This document describes Math::Random::Normal::Leva version 0.01
+This document describes Math::Random::Normal::Leva version 0.02
 
 =head1 SYNOPSIS
 
